/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.viewer;

import java.awt.Color;
import it.tidalwave.metadata.spi.MetadataItemEnhancer;
import it.tidalwave.metadata.viewer.mock.MetadataItemMock;
import it.tidalwave.metadata.viewer.mock.PaneMock;
import it.tidalwave.metadata.spi.TestLoggingSupport;
import it.tidalwave.metadata.mock.MetadataItemHolderMock;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class MetadataItemPaneSupportTest extends TestLoggingSupport
  {
    private PaneMock pane;

    @Before
    public void setUp() 
      {
        pane = new PaneMock();
      }

    @After
    public void tearDown() 
      {
        pane = null;
      }
    
    @Test
    public void testBind1()
      {
        final MetadataItemMock item = MetadataItemEnhancer.createEnhancedItem(new MetadataItemMock());
        item.setName("the name");
        pane.bind(new MetadataItemHolderMock<MetadataItemMock>(item));
        assertEquals("the name", item.getName());
        assertEquals(item.getName(), pane.tfName.getText());
      }
    
    @Test
    public void testBind2()
      {
        final MetadataItemMock item = MetadataItemEnhancer.createEnhancedItem(new MetadataItemMock());
        pane.bind(new MetadataItemHolderMock<MetadataItemMock>(item));
        pane.tfName.setText("the name");
        assertEquals("the name", item.getName());
      }
    
    @Test
    public void testSetAvailabilityOptionVisible()
      {
        pane.setAvailabilityOptionVisible(true);
        assertTrue(pane.isAvailabilityOptionVisible());
        assertTrue(pane.cbNameAvailable.isVisible());
        pane.setAvailabilityOptionVisible(false);
        assertFalse(pane.isAvailabilityOptionVisible());
        assertFalse(pane.cbNameAvailable.isVisible());
      }
    
    @Test
    public void testSetForeground()
      {
        final Color color = new Color(10, 20, 40);
        pane.setForeground(color);
        assertEquals(color, pane.getForeground());
        assertEquals(color, pane.tfName.getForeground());
        assertEquals(color, pane.cbNameAvailable.getForeground());
      }
  }
