/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.viewer.converter;

import it.tidalwave.metadata.viewer.converter.FormatConverter;
import java.text.FieldPosition;
import java.text.Format;
import java.text.ParsePosition;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

class FormatMock extends Format
  {
    protected static final String PREFIX = "formatted:";
    
    @Override
    public StringBuffer format (final Object object, final StringBuffer toAppendTo, final FieldPosition pos) 
      {
        toAppendTo.append(PREFIX);
        toAppendTo.append(object.toString());
        return toAppendTo;
      }

    @Override
    public Object parseObject (final String source, final ParsePosition pos) 
      {
        if (source.startsWith(PREFIX))
          {
            pos.setIndex(source.length());
            return source.substring(PREFIX.length());
          }
        
        return null;
      }
  }

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class FormatConverterTest 
  {
    private FormatConverter<Object> converter;
            
    @Before
    public void setUp() 
      {
        converter = new FormatConverter<Object>(new FormatMock());
      } 

    @After
    public void tearDown() 
      {
        converter = null;
      }

    @Test
    public void convertForward() 
      {
        assertEquals(FormatMock.PREFIX + "foobar", converter.convertForward("foobar"));
      }

    @Test
    public void convertReverse() 
      {
        assertEquals("foobar", converter.convertReverse(FormatMock.PREFIX + "foobar"));
      }
    
    @Test
    public void convertReverseInvalid() 
      {
        assertNull(converter.convertReverse("bad prefix + foobar"));
      }
  }